@@ -81,7 +81,7 @@ def wrap_exception(notifier=None, publisher_id=None, event_type=None,
             # contain confidential information.
             try:
                 return f(self, context, *args, **kw)
-            except Exception, e:
+            except Exception as e:
                 with excutils.save_and_reraise_exception():
                     if notifier:
                         payload = dict(exception=e)
@@ -246,6 +246,10 @@ class ResourceClassNotFound(NotFound):
     message = _("ResourceClass  %(resource_class)s could not be found.")
 
 
+class NodeNotFound(NotFound):
+    message = _("Node %(node)s could not be found.")
+
+
 class NodeLocked(NotFound):
     message = _("Node %(node)s is locked by another process.")
 
